CheckoutCustomer class
Customer information for checkout.
Constructors
- CheckoutCustomer({required String email, String? firstName, String? lastName, String? phone})
-
Creates a new CheckoutCustomer.
const
Properties
- email → String
-
Customer email address.
final
- firstName → String?
-
Customer first name.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastName → String?
-
Customer last name.
final
- phone → String?
-
Customer phone number.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converts this customer to a map for template rendering.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited